#
# spec file for package python-sunpy
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
# docs directory needed for tests not in source archive
%bcond_with     test
Name:           python-sunpy
Version:        0.9.5
Release:        bp153.1.22
Summary:        SunPy: Python for Solar Physics
License:        BSD-2-Clause AND BSD-3-Clause AND Apache-2.0 AND MIT
Group:          Development/Languages/Python
Url:            https://github.com/sunpy/sunpy
Source0:        https://files.pythonhosted.org/packages/source/s/sunpy/sunpy-%{version}.tar.gz
Source100:      python-sunpy-rpmlintrc
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module astropy >= 1.0.0}
BuildRequires:  %{python_module astropy-helpers >= 1.0.0}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module matplotlib >= 1.1}
BuildRequires:  %{python_module numpy-devel > 1.7.1}
BuildRequires:  %{python_module pandas >= 0.12.0}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scikit-image}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module suds-jurko}
BuildRequires:  fdupes
BuildRequires:  python-backports.functools_lru_cache
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-astropy >= 1.0.0
Requires:       python-matplotlib >= 1.1
Requires:       python-numpy > 1.7.1
Requires:       python-pandas >= 0.12.0
Requires:       python-scipy
Recommends:     python-SQLAlchemy
Recommends:     python-beautifulsoup4
Recommends:     python-glymur
Recommends:     python-requests
Recommends:     python-scikit-image
Recommends:     python-suds-jurko
Recommends:     python-wcsaxes >= 0.8

%python_subpackages

%description
SunPy is a Python library for solar physics data analysis.

%prep
%setup -q -n sunpy-%{version}
chmod -x sunpy/data/test/cor1_20090615_000500_s4c1A.fts

%build
export CFLAGS="%{optflags}"
%python_exec setup.py build --offline

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%doc README.rst CHANGELOG.rst RELEASE.rst 
%license licenses/*
%{python_sitearch}/sunpy
%{python_sitearch}/sunpy-%{version}-py*.egg-info

%changelog
* Fri Jan  4 2019 Todd R <toddrme2178@gmail.com>
- Update to version 0.9.5
  + New Features
  * Added TimeUTime class to support utime. [#2409]
  * Example for fine-grained use of ticks and grids [#2435]
  * Maintiners Workflow Guide [#2411]
  * Decorator to append and/or prepend doc strings [#2386]
  * Adding `python setup.py test --figure-only` [#2557]
  * Fido.fetch now accepts pathlib.Path objects for path attribute.[#2559]
  * The `~sunpy.coordinates.HeliographicStonyhurst` coordinate system can now be specified
    using a cartesian system, which is sometimes known as the
    "Heliocentric Earth equatorial" (HEEQ) coordinate system. [#2437]
  + API Changes
  * `sunpy.coordinates.representation` has been removed. Longitude wrapping is now done in the constructor of the frames. [#2431]
  * Propagation of ``obstime`` in the coordinate frame transformation has changed, this means in general when transforming directly between frames (not `~astropy.coordinates.SkyCoord`) you will have to specify ``obstime`` in more places. [#2461]
  * Transforming between Heliographic Stonyhurst and Carrington now requires that ``obstime`` be defined and the same on both the input and output frames. [#2461]
  * Removed the figure return from .peek() [#2487]
  + Bug Fixes
  * Improve TimeSeriesBase docstring [#2399]
  * Validate that pytest-doctestplus is installed [#2388]
  * Fix use of self.wcs in plot in mapbase [#2398]
  * Updated docstring with pointer to access EVE data for other levels [#2402]
  * Fix broken links and redirections in documentation [#2403]
  * Fixes Documentation changes due to NumPy 1.14 [#2404]
  * Added docstrings to functions in dowload.py [#2415]
  * Clean up database doc [#2414]
  * rhessi.py now uses sunpy.io instead of astropy.io [#2416]
  * Remove Gamma usage in Map [#2424]
  * Changed requirements to python-dateutil [#2426]
  * Clarify coordinate system definitions [#2429]
  * Improve Map Peek when using draw_grid [#2442]
  * Add HCC --> HGS test [#2443]
  * Testing the transformation linking SunPy and Astropy against published values [#2454]
  * Fixed title bug in sunpy.timeseries.rhessi [#2477]
  * Allow LineAnimator to accept a varying x-axis [#2491]
  * Indexing Bug Fix to LineAnimator [#2560]
  * Output sphinx warnings to stdout [#2553]
  * Docstring improvement for LineAnimator [#2514]
  * move the egg_info builds to circleci [#2512]
  * Added tests for TraceMap [#2504]
  * Fix HGS frame constructor and HPC ``calculate_distance`` with SkyCoord constructor. [#2463]
  * removed `wavelnth` keyword in meta desc of Maps to avoid using non standard FITS keyword like `nan` [#2456]
  * The documentation build now uses the Sphinx configuration from sphinx-astropy rather than from astropy-helpers.[#2494]
  * Migrate to hypothesis.strategies.datetimes [#2368]
  * Prevent a deprecation warning due to truth values of Quantity [#2358]
  * Print a warning when heliographic longitude is set to it's default value of 0 [#2480]
  * parse_time now parses numpy.datetime64 correctly. [#2572]
* Mon Feb 26 2018 toddrme2178@gmail.com
- Update to version 0.8.4
  + Bug Fixes
  * Improve detection of ``SkyCoord`` frame instantiation when distance is
    `1*u.one`. This fixes a plotting bug with ``WCSAxes`` in Astropy 3.0 [#2465]
  * removed `wavelnth` keyword in meta desc of Maps to avoid using non standard FITS keyword like `nan` [#2427]
  * Change the default units for HPC distance from `u.km` to `None`. [#2465]
- Update to version 0.8.3
  + Bug Fixes
  * `~sunpy.net.dataretriever.clients.XRSClient` now reports time ranges of files correctly. [#2364]
  * Make parse_time work with datetime64s and pandas series [#2370]
  * CompositeMap axes scaling now uses map spatial units [#2310]
  * Moved license file to root of repository and updated README file [#2326]
  * Fix docstring formatting for net.vso.attrs [#2309]]
  * Fix coloring of ticks under matplotlib 2.0 default style [#2320]
  * Always index arrays with tuples in `ImageAnimator` [#2320]
  * Added links to possible attrs for FIDO in guide [#2317] [#2289]
  * Updated GitHub Readme [#2281] [#2283]
  * Fix matplotlib / pandas 0.21 bug in examples [#2336]
  * Fixes the off limb enhancement example [#2329]
  * Changes to masking hot pixels and picking bright pixels examples [#2325] [#2319]
  * Travis CI fix for numpy-dev build [#2340]
  * Updated masking brightest pixel example [#2338]
  * Changed TRAVIS cronjobs [#2338]
  * Support array values for `obstime` for coordinates and transformations [#2342] [#2346]
  * Updated Gallery off limb enhance example [#2337]
  * Documentation fixes for VSO [#2354] [#2353]
  * All tests within the documentation have been fixed [#2343]
  * Change to using pytest-remotedata for our online tests [#2345]
  * Fixed upstream astropy/numpy documentation issues [#2359]
  * Documentation for Map improved [#2361]
  * Fix the output units of pixel_to_world [#2362]
  * Documentation for Database improved [#2355]
  * Added test for mapsave [#2365]
  * Documentation for Sun improved [#2369]
* Thu Jun 22 2017 alarrosa@suse.com
- Initial release of python-sunpy 0.7.8
